﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace Nlgp1 {

	internal partial class Form1 : Form {

		// フォームウィンドウが作られたときに呼ばれる
		public Form1() {
			// マップシートの内容
			this.sheet = new CellType[,] {
				{ CellType.Wall, CellType.Wall, CellType.Wall, CellType.Wall, CellType.Wall, CellType.Wall, CellType.Wall, CellType.Wall },
				{ CellType.Wall, CellType.None, CellType.None, CellType.None, CellType.None, CellType.None, CellType.None, CellType.Wall },
				{ CellType.Wall, CellType.None, CellType.None, CellType.None, CellType.None, CellType.None, CellType.None, CellType.Wall },
				{ CellType.Wall, CellType.None, CellType.None, CellType.None, CellType.None, CellType.None, CellType.None, CellType.Wall },
				{ CellType.Wall, CellType.None, CellType.None, CellType.None, CellType.None, CellType.None, CellType.Goal, CellType.Wall },
				{ CellType.Wall, CellType.Wall, CellType.Wall, CellType.Wall, CellType.Wall, CellType.Wall, CellType.Wall, CellType.Wall },
			};
			// あなたの最初のY座標
			this.youY = 1;
			// あなたの最初のX座標
			this.youX = 1;
			this.InitializeComponent();
		}

		// 描画する
		private void Draw(Graphics graphics) {
			// Y軸方向にすべてのセルを見る
			for (int y = 0; y < this.sheet.GetLength(0); ++y) {
				// X軸方向にすべてのセルを見る
				for (int x = 0; x < this.sheet.GetLength(1); ++x) {
					// 今見ているセルが
					switch (this.sheet[y, x]) {
					// 空なら
					case CellType.None:
						break;
					// 壁なら
					case CellType.Wall:
						// 黒いブラシを作る
						using (Brush brush = new SolidBrush(Color.Black)) {
							// 四角で塗りつぶす
							graphics.FillRectangle(
								brush,
								x * 16 + 1,
								y * 16 + 1,
								16 - (1 + 1),
								16 - (1 + 1));
						}
						break;
					// ゴールなら
					case CellType.Goal:
						// 青いブラシを作る
						using (Brush brush = new SolidBrush(Color.Blue)) {
							// 四角で塗りつぶす
							graphics.FillRectangle(
								brush,
								x * 16 + 1,
								y * 16 + 1,
								16 - (1 + 1),
								16 - (1 + 1));
						}
						break;
					}
				}
			}
			// 赤いブラシを作る
			using (Brush brush = new SolidBrush(Color.Red)) {
				// あなたの位置を丸で塗りつぶす
				graphics.FillEllipse(
					brush,
					this.youX * 16 + 1,
					this.youY * 16 + 1,
					16 - (1 + 1),
					16 - (1 + 1));
			}
		}

		// 描画が必要なときに呼ばれる
		private void Form1_Paint(object sender, PaintEventArgs e) {
			// 描画する
			this.Draw(e.Graphics);
		}

		// キーが押されたときに呼ばれる
		private void Form1_KeyDown(object sender, KeyEventArgs e) {
			// 方向キーが押されたなら
			if (Keys.Left <= e.KeyCode && e.KeyCode <= Keys.Down) {
				// あなたの座標をコピーする
				int y = this.youY;
				int x = this.youX;
				switch (e.KeyCode) {
				// 左が押されたなら
				case Keys.Left:
					// コピーを左へ動かす
					x -= 1;
					break;
				// 上が押されたなら
				case Keys.Up:
					// コピーを上へ動かす
					y -= 1;
					break;
				// 右が押されたなら
				case Keys.Right:
					// コピーを右へ動かす
					x += 1;
					break;
				// 下が押されたなら
				case Keys.Down:
					// コピーを下へ動かす
					y += 1;
					break;
				}
				// 動いた先が壁でないなら
				if (sheet[y, x] != CellType.Wall) {
					// コピーの座標へあなたを実際に動かす
					this.youY = y;
					this.youX = x;
					// 描画先を作る
					using (Graphics graphics = this.CreateGraphics()) {
						// 描画先を一旦消す
						graphics.Clear(this.BackColor);
						// 描画する
						this.Draw(graphics);
					}
				}
			}
		}

		// マップを保持するシート
		private CellType[,] sheet;
		// あなたのY座標
		private int youY;
		// あなたのX座標
		private int youX;
	}

	// マップの各セルの種類
	internal enum CellType {
		// 空
		None,
		// 壁
		Wall,
		// ゴール
		Goal,
	}
}
